| Title: | Exhaustive Chemical Enumeration for United Formula Annotation |
|---|---|
| Description: | A pipeline to annotate a number of peaks from the 'IDSL.IPA' peaklists using an exhaustive chemical enumeration-based approach. This package can perform elemental composition calculations using the following 15 elements : C, B, Br, Cl, K, S, Si, N, H, As, F, I, Na, O, and P. |
| Authors: | Sadjad Fakouri-Baygi [aut]
|
| Maintainer: | Dinesh Barupal <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.9.1 |
| Built: | 2026-05-25 10:19:33 UTC |
| Source: | https://github.com/idslme/idsl.ufax |
This function runs the exhaustive chemical enumeration part of the IDSL.UFAx pipeline.
UFAx_workflow(spreadsheet)UFAx_workflow(spreadsheet)
spreadsheet |
IDSL.UFAx parameter spreadsheet |
The MolecularFormulaAnnotationTable is saved in the assigned folder in the parameter spreadsheet.
You should load the IDSL.UFA package to run the IDSL.UFAx functions.
library(IDSL.UFAx) s_path <- system.file("extdata", package = "IDSL.UFAx") SSh1 <- paste0(s_path,"/UFAx_parameters.xlsx") temp_wd <- tempdir() # update this address temp_wd_zip <- paste0(temp_wd,"/003.mzML_UFAx_testfiles.zip") spreadsheet <- readxl::read_xlsx(SSh1) download.file( paste0("https://github.com/idslme/IDSL.UFAx/blob/main/UFAx_educational_files/", "003.mzML_UFAx_testfiles.zip?raw=true"), destfile = temp_wd_zip, mode = "wb") unzip(temp_wd_zip, exdir = temp_wd) spreadsheet[1, 4] <- temp_wd spreadsheet[3, 4] <- temp_wd spreadsheet[6, 4] <- temp_wd spreadsheet[5, 4] <- "seq(1, 100, 1)" # peak IDs to process UFAx_results <- UFAx_workflow(spreadsheet)library(IDSL.UFAx) s_path <- system.file("extdata", package = "IDSL.UFAx") SSh1 <- paste0(s_path,"/UFAx_parameters.xlsx") temp_wd <- tempdir() # update this address temp_wd_zip <- paste0(temp_wd,"/003.mzML_UFAx_testfiles.zip") spreadsheet <- readxl::read_xlsx(SSh1) download.file( paste0("https://github.com/idslme/IDSL.UFAx/blob/main/UFAx_educational_files/", "003.mzML_UFAx_testfiles.zip?raw=true"), destfile = temp_wd_zip, mode = "wb") unzip(temp_wd_zip, exdir = temp_wd) spreadsheet[1, 4] <- temp_wd spreadsheet[3, 4] <- temp_wd spreadsheet[6, 4] <- temp_wd spreadsheet[5, 4] <- "seq(1, 100, 1)" # peak IDs to process UFAx_results <- UFAx_workflow(spreadsheet)